@@ -158,8 +158,8 @@ class Transport extends EventEmitter {
     }
 
     const request = this.createHttpRequest({
-      path : '/session',
-      data : body
+      path: '/session',
+      data: body
     });
 
     request
@@ -310,8 +310,32 @@ class Transport extends EventEmitter {
     return !shouldIgnore;
   }
 
+  static getBrowserName(settings) {
+    let {browserName} = settings.desiredCapabilities;
+        
+    // Better support for Appium, if the browserName has explicitly been set to null we can skip all further checks
+    if (browserName === null) {
+      return browserName;
+    }
+
+    if (browserName !== BrowserName.EDGE) {
+      browserName = browserName.toLowerCase();
+    }
+
+    const browsersList = Object.values(BrowserName);
+
+    if (browsersList.includes(browserName)) {
+      return browserName;
+    }
+
+    const didYouMean = require('didyoumean');
+    const resultMeant = didYouMean(browserName, browsersList);
+
+    throw new Error(`Unknown browser: "${browserName}"${resultMeant ? ('; did you mean "' + resultMeant + '"?') : ''}`);
+  }
+
   static adaptWebdriverSettings(settings, usingSeleniumServer = false) {
-    const browserName = settings.desiredCapabilities.browserName.toLowerCase();
+    let browserName = Transport.getBrowserName(settings);
 
     if (settings.webdriver.port === 443 && settings.webdriver.ssl === undefined) {
       settings.webdriver.ssl = true;
@@ -335,13 +359,15 @@ class Transport extends EventEmitter {
         settings.webdriver.use_legacy_jsonwire = false;
         break;
 
+      case BrowserName.EDGE:
       case BrowserName.CHROME: {
-        const {chromeOptions = {}} = settings.desiredCapabilities;
-        if (chromeOptions.w3c) {
+        const {chromeOptions = {}, 'goog:chromeOptions': googChromeOpts = {}} = settings.desiredCapabilities;
+        const {edgeOptions = {}, 'ms:edgeOptions': msEdgeOpts = {}} = settings.desiredCapabilities;
+
+        if (chromeOptions.w3c || googChromeOpts.w3c || msEdgeOpts.w3c || edgeOptions.w3c) {
           settings.webdriver.use_legacy_jsonwire = false;
         }
       }
-
     }
 
     if (settings.webdriver.use_legacy_jsonwire === undefined) {
